Atatus APM agent for Python
===========================================

This is the official `Atatus Python APM agent`_.

This package allows you to monitor your python application for any performance issues and crashes.
Drill down slow database queries, slow third party requests, and more. Support is available for popular frameworks like Django and Flask.


Installation
--------------

The library can be installed using pip::

    pip install atatus


Resources
-----------

- `Django installation`_
- `Flask installation`_
- `Release notes`_


Copyright
----------

Copyright (c) 2014-2025 Atatus. All rights reserved.


.. _`Atatus Python APM agent`: https://www.atatus.com
.. _`Django installation`: https://docs.atatus.com/docs/application-monitoring/python-agent/installation/django.html
.. _`Flask installation`: https://docs.atatus.com/docs/application-monitoring/python-agent/installation/flask.html
.. _`Release notes`: https://docs.atatus.com/docs/release-notes/python.html

